<?php

namespace Drupal\layout_builder_enhancements\EventSubscriber;

use Symfony\Component\EventDispatcher\EventSubscriberInterface;
use Drupal\layout_builder\LayoutBuilderEvents;
use Drupal\layout_builder\Event\SectionComponentBuildRenderArrayEvent;
use Drupal\layout_builder_enhancements\Plugin\Block\ViewBlock;

/**
 * EventSubscriber for layout render event.
 */
class ViewEventSubscriber implements EventSubscriberInterface {

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    return [
      LayoutBuilderEvents::SECTION_COMPONENT_BUILD_RENDER_ARRAY => [
        'onBuildRender',
        100,
      ],
    ];
  }

  /**
   * Event render function.
   */
  public function onBuildRender(SectionComponentBuildRenderArrayEvent $event) {
    $block = $event->getPlugin();
    if (!$block instanceof ViewBlock) {
      return;
    }
    $build = $event->getBuild();
    $offset = $this->getOffset($block->getDerivativeId());
    $block->setOffset($offset);
    $block->inPreview($event->inPreview());
    $build['content'] = $block->build();
    $event->setBuild($build);
  }

  /**
   * Helper function for retrieve a offset.
   */
  protected function getOffset($id) {
    $value = &drupal_static(__FUNCTION__);
    if ($value == NULL) {
      $value = [];
    }
    if (!isset($value[$id])) {
      $value[$id] = -1;
    }
    $value[$id]++;
    return $value[$id];
  }

}
